Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(225)

Unified Diff: ash/display/display_layout_store.h

Issue 1150913002: Save and restore unified mode (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix leak Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/display/display_layout.cc ('k') | ash/display/display_layout_store.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/display/display_layout_store.h
diff --git a/ash/display/display_layout_store.h b/ash/display/display_layout_store.h
index a9675371269867c1f2e354522c4680cb21f1c1dc..6841ea906aa5f8057d0f6b408be2cde03a1a49d1 100644
--- a/ash/display/display_layout_store.h
+++ b/ash/display/display_layout_store.h
@@ -37,11 +37,12 @@ class ASH_EXPORT DisplayLayoutStore {
DisplayLayout ComputeDisplayLayoutForDisplayIdPair(
const DisplayIdPair& display_pair);
// Update the mirrored flag in the display layout for
// |display_pair|. This creates new display layout if no layout is
// registered for |display_pair|.
- void UpdateMirrorStatus(const DisplayIdPair& display_pair,
- bool mirrored);
+ void UpdateMultiDisplayState(const DisplayIdPair& display_pair,
+ bool mirrored,
+ bool default_unified);
// Update the |primary_id| in the display layout for
// |display_pair|. This creates new display layout if no layout is
« no previous file with comments | « ash/display/display_layout.cc ('k') | ash/display/display_layout_store.cc » ('j') | no next file with comments »
@@ -37,11 +37,12 @@ class ASH_EXPORT DisplayLayoutStore {
DisplayLayout ComputeDisplayLayoutForDisplayIdPair(
const DisplayIdPair& display_pair);
- // Update the mirrored flag in the display layout for
+ // Update the multi display state in the display layout for
// |display_pair|. This creates new display layout if no layout is
// registered for |display_pair|.

Powered by Google App Engine
This is Rietveld 408576698